pub enum DataCmd {
StoreChunk(Chunk),
Register(RegisterCmd),
Spentbook(SpentbookCmd),
}Expand description
Data cmds - creating, updating, or removing data.
See the types module documentation for more details of the types supported by the Safe
Network, and their semantics.
Variants
StoreChunk(Chunk)
Chunk write operation.
Register(RegisterCmd)
Register write operation.
Spentbook(SpentbookCmd)
Spentbook write operation.
Implementations
Sourceimpl DataCmd
impl DataCmd
Sourcepub fn to_error_response(&self, error: Error) -> CmdResponse
pub fn to_error_response(&self, error: Error) -> CmdResponse
Creates a Response containing an error, with the Response variant corresponding to the Request.