Enum sn_interface::messaging::data::RegisterCmd
source · [−]pub enum RegisterCmd {
Create {
cmd: SignedRegisterCreate,
section_auth: SectionAuth,
},
Edit(SignedRegisterEdit),
}Expand description
A Register cmd that is stored in a log on Adults.
Variants
Create
Fields
cmd: SignedRegisterCreateThe user signed op.
section_auth: SectionAuthSection signature over the operation, verifying that it was paid for.
Create a new Register on the network.
Edit(SignedRegisterEdit)
Edit the Register.
Implementations
sourceimpl RegisterCmd
impl RegisterCmd
sourcepub fn error(&self, error: Error) -> CmdError
pub fn error(&self, error: Error) -> CmdError
Creates a Response containing an error, with the Response variant corresponding to the Request variant.
sourcepub fn name(&self) -> XorName
pub fn name(&self) -> XorName
Returns the name of the register. This is not a unique identifier.
sourcepub fn dst_address(&self) -> RegisterAddress
pub fn dst_address(&self) -> RegisterAddress
Returns the dst address of the register.