Enum sn_interface::messaging::AuthKind
source · [−]pub enum AuthKind {
Service(ServiceAuth),
Node(NodeAuth),
NodeBlsShare(BlsShareAuth),
}Expand description
Source authority of a message.
Source of message and authority to send it. Authority is validated by the signature. Messages do not need to sign this field as it is all verifiable (i.e. if the signature validates against the public key and we know the public key then we are good. If the proof is not recognised we can ask for a longer chain that can be recognised).
Variants
Service(ServiceAuth)
A data message, with the requesting peer’s authority.
Authority is needed to access private data, such as reading or writing a private file.
Node(NodeAuth)
A message from a Node with its own independent authority.
Node authority is needed when nodes send messages directly to other nodes.
NodeBlsShare(BlsShareAuth)
A message from an Elder node with its share of the section authority.
Section share authority is needed for messages related to section administration, such as DKG and relocation.
Implementations