Struct sn_interface::messaging::SectionAuthorityProvider
source · [−]pub struct SectionAuthorityProvider {
pub prefix: Prefix,
pub public_key_set: PublicKeySet,
pub elders: BTreeMap<XorName, SocketAddr>,
pub members: BTreeMap<XorName, NodeState>,
pub membership_gen: Generation,
}Expand description
Details of section authority.
A new SectionAuthorityProvider is created whenever the elders change, due to an elder being
added or removed, or the section splitting or merging.
Fields
prefix: PrefixThe section prefix. It matches all the members’ names.
public_key_set: PublicKeySetPublic key set of the section.
elders: BTreeMap<XorName, SocketAddr>The section’s complete set of elders as a map from their name to their socket address.
members: BTreeMap<XorName, NodeState>The section members at the time of this elder churn.
membership_gen: GenerationThe membership generation this SAP was instantiated on
Implementations
sourceimpl SectionAuthorityProviderMsg
impl SectionAuthorityProviderMsg
pub fn into_state(self) -> SectionAuthorityProvider