pub enum JoinResponse {
    ResourceChallenge {
        data_size: usize,
        difficulty: u8,
        nonce: [u8; 32],
        nonce_signature: Signature,
    },
    Retry {
        section_auth: SectionAuthorityProvider,
        section_signed: KeyedSig,
        proof_chain: SecuredLinkedList,
        expected_age: u8,
    },
    Redirect(SectionAuthorityProvider),
    Approved {
        genesis_key: BlsPublicKey,
        section_auth: SectionAuth<SectionAuthorityProvider>,
        section_chain: SecuredLinkedList,
        decision: Decision<NodeState>,
    },
    Rejected(JoinRejectionReason),
}
Response to a request to join a section

Variants

ResourceChallenge

Fields

data_size: usize
difficulty: u8

how hard the challenge should be to solve

nonce: [u8; 32]
nonce_signature: Signature

Challenge sent from existing elder nodes to the joining peer for resource proofing.

Retry

Fields

section_auth: SectionAuthorityProvider

Current SectionAuthorityProvider of the section.

section_signed: KeyedSig

Section signature over the SectionAuthorityProvider.

proof_chain: SecuredLinkedList

Section chain truncated from the section key found in the join request.

expected_age: u8

The age of the node as expected by the section.

Up to date section information for a joining peer to retry its join request with

Redirect(SectionAuthorityProvider)

Response redirecting a joining peer to join a different section, containing addresses of nodes that are closer (than the recipient) to the requested name. The JoinRequest should be re-sent to these addresses.

Approved

Fields

genesis_key: BlsPublicKey

Network genesis key (needed to validate) section_chain

section_auth: SectionAuth<SectionAuthorityProvider>

SectionAuthorityProvider Signed by (current section)

section_chain: SecuredLinkedList

Full verifiable section chain

decision: Decision<NodeState>

Current node’s state

Message sent to joining peer containing the necessary info to become a member of the section.

Rejected(JoinRejectionReason)

Join was rejected