pub struct SectionKeysProvider { /* private fields */ }Expand description
Struct that holds the current section keys and helps with new key generation. Implementation of super simple cache, for no more than a handfull of items.
Implementations
sourceimpl SectionKeysProvider
impl SectionKeysProvider
sourcepub fn new(current: Option<SectionKeyShare>) -> Self
pub fn new(current: Option<SectionKeyShare>) -> Self
Constructor.
Returns the most recently added key.
sourcepub fn sign_with(
&self,
data: &[u8],
public_key: &PublicKey
) -> Result<(usize, SignatureShare)>
pub fn sign_with(
&self,
data: &[u8],
public_key: &PublicKey
) -> Result<(usize, SignatureShare)>
Uses the secret key from cache, corresponding to the provided public key.
sourcepub fn insert(&mut self, share: SectionKeyShare)
pub fn insert(&mut self, share: SectionKeyShare)
Adds a new key to the cache, and removes the oldest key if cache size is exceeded.