SectionsDAG

Struct SectionsDAG 

pub struct SectionsDAG { /* private fields */ }
A Merkle DAG of BLS keys where every key is signed by its parent key, except the genesis one.

Implementations

Source

impl SectionsDAG

pub fn new(genesis_key: PublicKey) -> Self

Creates a new DAG containing only the genesis_key

pub fn verify_and_insert( &mut self, parent_key: &PublicKey, key: PublicKey, signature: Signature, ) -> Result<()>

Insert new key into the DAG. parent_key must exist in the DAG and must validate signature, otherwise error is returned.

pub fn partial_dag(&self, from: &PublicKey, to: &PublicKey) -> Result<Self>

Get a partial SectionsDAG from the from key to the to key Returns Error::KeyNotFound if the to key is not present in the DAG; Returns Error::InvalidBranch if the from key is not found or is not a direct ancestor of the to key

pub fn single_branch_dag_for_key( &self, key: &PublicKey, ) -> Result<(Self, PublicKey)>

Get a partial SectionsDAG with a single branch which contains the given key, from the genesis to the last key of any of its children branches. It also returns the last key of the (single) branch the returned DAG contains. Returns Error::KeyNotFound if the key key is not present in the DAG;

pub fn merge(&mut self, other: Self) -> Result<()>

Update our current SectionsDAG with the keys from another SectionsDAG Returns Error::InvalidSignature if the provided DAG fails signature verification Returns Error::KeyNotFound if the genesis_key of either of the DAGs is not present in the other

pub fn genesis_key(&self) -> &PublicKey

Returns the genesis key

pub fn leaf_keys(&self) -> BTreeSet<PublicKey>

Returns the list of the leaf keys

pub fn keys(&self) -> impl Iterator<Item = PublicKey> + '_

Iterator over all the keys in the SectionsDAG

pub fn has_key(&self, key: &PublicKey) -> bool

Returns whether key is present in this SectionsDAG.

pub fn self_verify(&self) -> bool

Verify every BLS key in the DAG is proven (signed) by its parent key, except the genesis key

pub fn check_trust<I>(&self, trusted_keys: I) -> bool
where I: IntoIterator<Item = PublicKey>,

Returns true if the genesis_key is present in the list of trusted_keys

pub fn get_parent_key(&self, key: &PublicKey) -> Result<Option<PublicKey>>

Returns the parent of the provided key. None is returned if we’re provided the genesis_key Can return Error::KeyNotFound

pub fn get_ancestors(&self, key: &PublicKey) -> Result<Vec<PublicKey>>

Returns the ancestors of the provided key. List is empty if we’re provided the genesis_key Can return Error::KeyNotFound

pub fn get_child_keys(&self, key: &PublicKey) -> Result<Vec<PublicKey>>

Returns the immediate children of a given section key. List is empty if the section is a leaf. Can return Error::KeyNotFound

pub fn last_key(&self) -> Result<PublicKey>

Returns the last key if the DAG contains a single branch Else returns Error::MultipleBranchError