Enum sn_interface::messaging::system::JoinResponse
source · [−]pub enum JoinResponse {
ResourceChallenge {
data_size: usize,
difficulty: u8,
nonce: [u8; 32],
nonce_signature: Signature,
},
Retry {
section_auth: SectionAuthorityProvider,
section_signed: KeyedSig,
proof_chain: SecuredLinkedList,
expected_age: u8,
},
Redirect(SectionAuthorityProvider),
Approved {
genesis_key: BlsPublicKey,
section_auth: SectionAuth<SectionAuthorityProvider>,
section_chain: SecuredLinkedList,
decision: Decision<NodeState>,
},
Rejected(JoinRejectionReason),
}Expand description
Response to a request to join a section
Variants
ResourceChallenge
Fields
data_size: usizedifficulty: u8how hard the challenge should be to solve
nonce_signature: SignatureChallenge sent from existing elder nodes to the joining peer for resource proofing.
Retry
Fields
section_auth: SectionAuthorityProviderCurrent SectionAuthorityProvider of the section.
section_signed: KeyedSigSection signature over the SectionAuthorityProvider.
proof_chain: SecuredLinkedListSection chain truncated from the section key found in the join request.
expected_age: u8The age of the node as expected by the section.
Up to date section information for a joining peer to retry its join request with
Redirect(SectionAuthorityProvider)
Response redirecting a joining peer to join a different section,
containing addresses of nodes that are closer (than the recipient) to the
requested name. The JoinRequest should be re-sent to these addresses.
Approved
Fields
genesis_key: BlsPublicKeyNetwork genesis key (needed to validate) section_chain
section_auth: SectionAuth<SectionAuthorityProvider>SectionAuthorityProvider Signed by (current section)
section_chain: SecuredLinkedListFull verifiable section chain
Message sent to joining peer containing the necessary info to become a member of the section.
Rejected(JoinRejectionReason)
Join was rejected